Skip to contents

A fully synthetic REDCap-shaped project list used in package examples, vignettes, and tests. The project is longitudinal and includes demographics, follow-up, checkbox, validation, completion status, and repeating instrument fields.

Usage

mock_redcap_project

Format

A list with REDCap API-like data frames:

data

Synthetic REDCap records.

metadata

Synthetic REDCap data dictionary metadata.

events

Synthetic longitudinal event metadata.

event_instruments

Synthetic event-instrument mapping.

instruments

Synthetic instrument labels.

repeating_instruments

Synthetic repeating instrument settings.

project_info

Synthetic project-level metadata.

Generated by data-raw/mock-data.R.